@@ -2,7 +2,7 @@
 //
 // Vector.cpp: Rcpp R/C++ interface class library -- Vector unit tests
 //
-// Copyright (C) 2012 - 2015    Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2012 - 2018    Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -747,22 +747,42 @@ CharacterVector CharacterVector_test_const_proxy(const CharacterVector x){
 
 // [[Rcpp::export]]
 NumericVector sort_numeric(NumericVector x) {
-  return x.sort();
+    return x.sort();
 }
 
 // [[Rcpp::export]]
 IntegerVector sort_integer(IntegerVector x) {
-  return x.sort();
+    return x.sort();
 }
 
 // [[Rcpp::export]]
 CharacterVector sort_character(CharacterVector x) {
-  return x.sort();
+    return x.sort();
 }
 
 // [[Rcpp::export]]
 LogicalVector sort_logical(LogicalVector x) {
-  return x.sort();
+    return x.sort();
+}
+
+// [[Rcpp::export]]
+NumericVector sort_numeric_desc(NumericVector x) {
+    return x.sort(true);
+}
+
+// [[Rcpp::export]]
+IntegerVector sort_integer_desc(IntegerVector x) {
+    return x.sort(true);
+}
+
+// [[Rcpp::export]]
+CharacterVector sort_character_desc(CharacterVector x) {
+    return x.sort(true);
+}
+
+// [[Rcpp::export]]
+LogicalVector sort_logical_desc(LogicalVector x) {
+    return x.sort(true);
 }
 
 // [[Rcpp::export]]
@@ -828,3 +848,23 @@ String vec_print_integer(IntegerVector v) {
 IntegerVector vec_subset(IntegerVector x, IntegerVector y) {
     return x[y - 1];
 }
+
+// [[Rcpp::export]]
+int CharacterVectorNoProtect(Vector<STRSXP, NoProtectStorage> s){
+    s[0] = "";
+    return s.size();
+}
+
+// [[Rcpp::export]]
+CharacterVector CharacterVectorNoProtect_crosspolicy(Vector<STRSXP, NoProtectStorage> s){
+    CharacterVector s2(1) ;
+    s2[0] = s[0];
+    return s;
+}
+
+// [[Rcpp::export]]
+List ListNoProtect_crosspolicy(Vector<VECSXP, NoProtectStorage> data){
+    List data2(1) ;
+    data2[0] = data[0];
+    return data2;
+}
